OboPatchOp

Enum OboPatchOp 

pub enum OboPatchOp {
    SetName {
        term_id: String,
        value: String,
    },
    AddSynonym {
        term_id: String,
        value: String,
        scope: String,
    },
    RemoveSynonym {
        term_id: String,
        value: String,
        scope: Option<String>,
    },
    AddDef {
        term_id: String,
        value: String,
    },
    RemoveDef {
        term_id: String,
    },
    AddXref {
        term_id: String,
        xref: String,
    },
    RemoveXref {
        term_id: String,
        xref: String,
    },
    SetNamespace {
        term_id: String,
        namespace: String,
    },
    SetDeprecated {
        term_id: String,
        value: bool,
    },
    AddIsA {
        term_id: String,
        parent_id: String,
    },
    RemoveIsA {
        term_id: String,
        parent_id: String,
    },
}
OBO patch operation (ADR-0019).

Variants



SetName

Fields

term_id: String
value: String


AddSynonym

Fields

term_id: String
value: String
scope: String


RemoveSynonym

Fields

term_id: String
value: String
scope: Option<String>

When set, only a synonym with this scope is removed. When omitted and multiple scopes share the same text, apply fails.



AddDef

Fields

term_id: String
value: String


RemoveDef

Fields

term_id: String


AddXref

Fields

term_id: String
xref: String


RemoveXref

Fields

term_id: String
xref: String


SetNamespace

Fields

term_id: String
namespace: String


SetDeprecated

Fields

term_id: String
value: bool


AddIsA

Fields

term_id: String
parent_id: String


RemoveIsA

Fields

term_id: String
parent_id: String